A small demo library for a Medium publication about publishing libraries.

## Installation 

```python
pip3 install multiply_internship_2024
```
## Get Started
How to multiply one number by another with this lib:
```python
from multiply_internship_2024 import multiplication

multiplication = Multiplication(2)

result = multiplication.multiply(5)
```
